NoScreenshot class
A class that provides a platform-agnostic way to disable screenshots.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
screenshotStream
→ Stream<
ScreenshotSnapshot> -
Stream to screenshot activities ScreenshotSnapshot
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
screenshotOff(
) → Future< bool> -
Return
trueif screenshot capabilities has been successfully disabled or is currently disabled andfalseotherwise. throwUnmimplementedErrorif not implement -
screenshotOn(
) → Future< bool> -
Return
trueif screenshot capabilities has been successfully enabled or is currently enabled andfalseotherwise. throwUnmimplementedErrorif not implement -
startScreenshotListening(
) → Future< void> - Start listening to screenshot activities
-
stopScreenshotListening(
) → Future< void> - Stop listening to screenshot activities
-
toggleScreenshot(
) → Future< bool> -
Return
trueif screenshot capabilities has been successfully toggle from it previous state andfalseif the attempt to toggle failed. throwUnmimplementedErrorif not implement -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Properties
- instance → NoScreenshot
-
no setter