MethodChannelNoScreenshot class

An implementation of NoScreenshotPlatform that uses method channels.

Constructors

MethodChannelNoScreenshot()

Properties

eventChannel EventChannel
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshotStream Stream<ScreenshotSnapshot>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
screenshotOff() Future<bool>
screenshotOn() Future<bool>
startScreenshotListening() Future<void>
stopScreenshotListening() Future<void>
toggleScreenshot() Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited